==> firefox-58.0b13.source.tar.xz: firefox-58.0b13/browser/extensions/activity-stream/prerendered/locales/kn/activity-stream-strings.js <==
// Note - this is a generated file.
window.gActivityStreamStrings = {
  "newtab_page_title": "ಹೊಸ ಹಾಳೆ",
  "default_label_loading": "ಲೋಡ್ ಆಗುತ್ತಿದೆ…",
  "header_top_sites": "ಪ್ರಮುಖ ತಾಣಗಳು",
  "header_stories": "ಪ್ರಮುಖ ಸುದ್ದಿಗಳು",
  "header_highlights": "ಮುಖ್ಯಾಂಶಗಳು",
  "header_visit_again": "ಮತ್ತೆ ಭೇಟಿಕೊಡು",
  "header_bookmarks": "ಇತ್ತೀಚಿಗೆ ಮಾಡಲಾದ ಬುಕ್‌ಮಾರ್ಕುಗಳು",
  "header_recommended_by": "{provider} ರಿಂದ ಶಿಫಾರಸುಮಾಡುಲಾಗಿದೆ",
  "header_bookmarks_placeholder": "ನಿಮ್ಮ ಹತ್ತಿರ ಇನ್ನೂ ಯಾವುದೇ ಪುಟಗುರುತುಗಳಿಲ್ಲ.",
  "header_stories_from": "ಯಿಂದ",
  "type_label_visited": "ಭೇಟಿ ನೀಡಲಾದ‍",
  "type_label_bookmarked": "ಪುಟಗುರುತು ಮಾಡಲಾದ",
  "type_label_synced": "ಮತ್ತೊಂದು ಸಾಧನದಿಂದ ಸಿಂಕ್ ಮಾಡಲಾಗಿದೆ",
  "type_label_recommended": "ಪ್ರಚಲಿತ",
  "type_label_open": "ತೆರೆ",
  "type_label_topic": "ವಿಷಯ",
  "type_label_now": "ಈಗ",
  "menu_action_bookmark": "ಪುಟ ಗುರುತು",
  "menu_action_remove_bookmark": "ಪುಟ ಗುರುತು ತೆಗೆ",
  "menu_action_copy_address": "ವಿಳಾಸವನ್ನು ನಕಲಿಸು",
  "menu_action_email_link": "ಇಮೈಲ್ ಕೊಂಡಿ…",
  "menu_action_open_new_window": "ಹೊಸ ಕಿಟಕಿಯಲ್ಲಿ ತೆರೆ",
  "menu_action_open_private_window": "ಹೊಸ ಖಾಸಗಿ ಕಿಟಕಿಯಲ್ಲಿ ತೆರೆ",
  "menu_action_dismiss": "ವಜಾಗೊಳಿಸು‍",
  "menu_action_delete": "ಇತಿಹಾಸದಿಂದ ಅಳಿಸು‍",
  "menu_action_pin": "ಪಿನ್",
  "menu_action_unpin": "ಅನ್‌ಪಿನ್",
  "confirm_history_delete_p1": "Are you sure you want to delete every instance of this page from your history?",
  "confirm_history_delete_notice_p2": "ಈ ಕಾರ್ಯವನ್ನು ರದ್ದುಗೊಳಿಸಲು ಸಾಧ್ಯವಿರುವುದಿಲ್ಲ.",
  "menu_action_save_to_pocket": "ಪಾಕೆಟ್‌ನಲ್ಲಿ ಉಳಿಸಿ‍",
  "search_for_something_with": "{search_term} ಅನ್ನು ಇದರಿಂದ ಹುಡುಕಿ:",
  "search_button": "ಹುಡುಕು",
  "search_header": "{search_engine_name} ನಿಂದ ಹುಡುಕಿ",
  "search_web_placeholder": "ಅಂತರ್ಜಾಲವನ್ನು ಹುಡುಕಿ",
  "search_settings": "ಹುಡುಕು ಸಿದ್ಧತೆಗಳನ್ನು ಬದಲಾಯಿಸು",
  "section_info_option": "ಮಾಹಿತಿ",
  "section_info_send_feedback": "ಅಭಿಪ್ರಾಯವನ್ನು ಕಳುಹಿಸಿ",
  "section_info_privacy_notice": "ಗೌಪ್ಯತಾ ಸೂಚನೆ",
  "section_disclaimer_topstories": "The most interesting stories on the web, selected based on what you read. From Pocket, now part of Mozilla.",
  "section_disclaimer_topstories_linktext": "Learn how it works.",
  "section_disclaimer_topstories_buttontext": "Okay, got it",
  "welcome_title": "ಹೊಸ ಹಾಳೆಗೆ ಸುಸ್ವಾಗತ",
  "welcome_body": "Firefox will use this space to show your most relevant bookmarks, articles, videos, and pages you’ve recently visited, so you can get back to them easily.",
  "welcome_label": "Identifying your Highlights",
  "time_label_less_than_minute": "<1ನಿ",
  "time_label_minute": "{number}ನಿ",
  "time_label_hour": "{number}ಗ",
  "time_label_day": "{number}ದಿ",
  "settings_pane_button_label": "ಹೊಸ ಹಾಳೆಯ ಪುಟವನ್ನು ಅಗತ್ಯಾನುಗುಣಗೊಳಿಸಿ",
  "settings_pane_header": "ಹೊಸ ಹಾಳೆಯ ಆದ್ಯತೆಗಳು",
  "settings_pane_body2": "ನೀವು ಈ ಪುಟದಲ್ಲಿ ಏನು ನೋಡಿತ್ತೀರೆಂದು ಆಯ್ಕೆಮಾಡಿ.",
  "settings_pane_search_header": "ಹುಡುಕು",
  "settings_pane_search_body": "ಹೊಸ ಹಾಳೆಯಿಂದ ಅಂತರ್ಜಾಲವನ್ನು ಹುಡುಕಿ.",
  "settings_pane_topsites_header": "ಪ್ರಮುಖ ತಾಣಗಳು",
  "settings_pane_topsites_body": "ನೀವು ಅತಿ ಹೆಚ್ಚು ನೋಡುವ ಜಾಲತಾಣಗಳಿಗೆ ಪ್ರವೇಶದ್ವಾರ.",
  "settings_pane_topsites_options_showmore": "ಎರಡು ಸಾಲುಗಳನ್ನು ಪ್ರದರ್ಶಿಸು",
  "settings_pane_bookmarks_header": "ಇತ್ತೀಚಿನ ಪುಟಗುರುತುಗಳು",
  "settings_pane_bookmarks_body": "Your newly created bookmarks in one handy location.",
  "settings_pane_visit_again_header": "ಮತ್ತೆ ಭೇಟಿಕೊಡು",
  "settings_pane_visit_again_body": "Firefox will show you parts of your browsing history that you might want to remember or get back to.",
  "settings_pane_highlights_header": "ಮುಖ್ಯಾಂಶಗಳು",
  "settings_pane_highlights_body2": "Find your way back to interesting things you’ve recently visited or bookmarked.",
  "settings_pane_highlights_options_bookmarks": "ಪುಟಗುರುತುಗಳು",
  "settings_pane_highlights_options_visited": "ಭೇಟಿ ನೀಡಿದ ತಾಣಗಳು",
  "settings_pane_snippets_header": "ಉಲ್ಲೇಖಗಳು",
  "settings_pane_snippets_body": "Read short and sweet updates from Mozilla about Firefox, internet culture, and the occasional random meme.",
  "settings_pane_done_button": "ಆಯಿತು",
  "settings_pane_topstories_options_sponsored": "Show Sponsored Stories",
  "edit_topsites_button_text": "‍ತಿದ್ದು",
  "edit_topsites_button_label": "Customize your Top Sites section",
  "edit_topsites_showmore_button": "‍ಹೆಚ್ಚು ತೋರಿಸು",
  "edit_topsites_showless_button": "ಕೆಲವೊಂದು ತೋರಿಸಿ",
  "edit_topsites_done_button": "ಆಯಿತು",
  "edit_topsites_pin_button": "ಈ ತಾಣವನ್ನು ಪಿನ್ ಮಾಡು",
  "edit_topsites_unpin_button": "ಈ ತಾಣವನ್ನು ಹೊರತೆಗೆ",
  "edit_topsites_edit_button": "ಈ ತಾಣವನ್ನು ಸಂಪಾದಿಸು",
  "edit_topsites_dismiss_button": "ಈ ತಾಣವನ್ನು ತೆಗೆದುಹಾಕು",
  "edit_topsites_add_button": "ಸೇರಿಸು",
  "topsites_form_add_header": "ಹೊಸ ಅಗ್ರ ತಾಣಗಳು",
  "topsites_form_edit_header": "ಅಗ್ರ ತಾಣಗಳನ್ನು ಸಂಪಾದಿಸಿ",
  "topsites_form_title_placeholder": "ಶೀರ್ಷಿಕೆಯನ್ನು ನಮೂದಿಸಿ",
  "topsites_form_url_placeholder": "ಒಂದು URL ಅನ್ನು ಟೈಪಿಸಿ ಅಥವಾ ನಕಲಿಸಿ",
  "topsites_form_add_button": "ಸೇರಿಸು",
  "topsites_form_save_button": "ಉಳಿಸು",
  "topsites_form_cancel_button": "ರದ್ದು ಮಾಡು",
  "topsites_form_url_validation": "ಸರಿಯಾದ URL ಬೇಕಾಗಿದೆ",
  "pocket_read_more": "ಜನಪ್ರಿಯವಾದ ವಿಷಯಗಳು:",
  "pocket_read_even_more": "ಹೆಚ್ಚು ಕತೆಗಳನ್ನು ನೋಡಿರಿ",
  "pocket_feedback_header": "The best of the web, curated by over 25 million people.",
  "pocket_description": "Discover high-quality content you might otherwise miss, with help from Pocket, now part of Mozilla.",
  "highlights_empty_state": "ವೀಕ್ಷಣೆ ಮಾಡಲು ಶುರುಮಾಡಿ, ಮತ್ತು ನಾವು ಇತ್ತೀಚೆಗೆ ಭೇಟಿ ನೀಡಿದ ಅಥವಾ ಬುಕ್‌ಮಾರ್ಕ್ ಮಾಡಲಾದ ಕೆಲವು ಶ್ರೇಷ್ಠ ಲೇಖನಗಳು, ವೀಡಿಯೊಗಳು ಮತ್ತು ಇತರ ಪುಟಗಳನ್ನು ನಾವು ತೋರಿಸುತ್ತೇವೆ.",
  "topstories_empty_state": "You’ve caught up. Check back later for more top stories from {provider}. Can’t wait? Select a popular topic to find more great stories from around the web.",
  "manual_migration_explanation2": "Try Firefox with the bookmarks, history and passwords from another browser.",
  "manual_migration_cancel_button": "ಪರವಾಗಿಲ್ಲ",
  "manual_migration_import_button": "ಈಗ ಆಮದು ಮಾಡು"
};

==> firefox-61.0b6.source.tar.xz: firefox-61.0/browser/extensions/activity-stream/prerendered/locales/kn/activity-stream-strings.js <==
// Note - this is a generated kn file.
window.gActivityStreamStrings = {
  "newtab_page_title": "ಹೊಸ ಹಾಳೆ",
  "header_top_sites": "ಪ್ರಮುಖ ತಾಣಗಳು",
  "header_highlights": "ಮುಖ್ಯಾಂಶಗಳು",
  "header_recommended_by": "{provider} ರಿಂದ ಶಿಫಾರಸುಮಾಡುಲಾಗಿದೆ",
  "context_menu_button_sr": "Open context menu for {title}",
  "section_context_menu_button_sr": "Open the section context menu",
  "type_label_visited": "ಭೇಟಿ ನೀಡಲಾದ‍",
  "type_label_bookmarked": "ಪುಟಗುರುತು ಮಾಡಲಾದ",
  "type_label_recommended": "ಪ್ರಚಲಿತ",
  "type_label_pocket": "Saved to Pocket",
  "type_label_downloaded": "Downloaded",
  "menu_action_bookmark": "ಪುಟ ಗುರುತು",
  "menu_action_remove_bookmark": "ಪುಟ ಗುರುತು ತೆಗೆ",
  "menu_action_open_new_window": "ಹೊಸ ಕಿಟಕಿಯಲ್ಲಿ ತೆರೆ",
  "menu_action_open_private_window": "ಹೊಸ ಖಾಸಗಿ ಕಿಟಕಿಯಲ್ಲಿ ತೆರೆ",
  "menu_action_dismiss": "ವಜಾಗೊಳಿಸು‍",
  "menu_action_delete": "ಇತಿಹಾಸದಿಂದ ಅಳಿಸು‍",
  "menu_action_pin": "ಪಿನ್",
  "menu_action_unpin": "ಅನ್‌ಪಿನ್",
  "confirm_history_delete_p1": "Are you sure you want to delete every instance of this page from your history?",
  "confirm_history_delete_notice_p2": "ಈ ಕಾರ್ಯವನ್ನು ರದ್ದುಗೊಳಿಸಲು ಸಾಧ್ಯವಿರುವುದಿಲ್ಲ.",
  "menu_action_save_to_pocket": "ಪಾಕೆಟ್‌ನಲ್ಲಿ ಉಳಿಸಿ‍",
  "menu_action_delete_pocket": "Delete from Pocket",
  "menu_action_archive_pocket": "Archive in Pocket",
  "menu_action_show_file_mac_os": "Show in Finder",
  "menu_action_show_file_windows": "Open Containing Folder",
  "menu_action_show_file_linux": "Open Containing Folder",
  "menu_action_show_file_default": "Show File",
  "menu_action_open_file": "Open File",
  "menu_action_copy_download_link": "Copy Download Link",
  "menu_action_go_to_download_page": "Go to Download Page",
  "menu_action_remove_download": "Remove from History",
  "search_button": "ಹುಡುಕು",
  "search_header": "{search_engine_name} ನಿಂದ ಹುಡುಕಿ",
  "search_web_placeholder": "ಅಂತರ್ಜಾಲವನ್ನು ಹುಡುಕಿ",
  "section_disclaimer_topstories": "The most interesting stories on the web, selected based on what you read. From Pocket, now part of Mozilla.",
  "section_disclaimer_topstories_linktext": "Learn how it works.",
  "section_disclaimer_topstories_buttontext": "Okay, got it",
  "prefs_home_header": "Firefox Home Content",
  "prefs_home_description": "Choose what content you want on your Firefox Home screen.",
  "prefs_section_rows_option": "{num} row;{num} rows",
  "prefs_search_header": "Web Search",
  "prefs_topsites_description": "The sites you visit most",
  "prefs_topstories_description2": "Great content from around the web, personalized for you",
  "prefs_topstories_options_sponsored_label": "Sponsored Stories",
  "prefs_topstories_sponsored_learn_more": "Learn more",
  "prefs_highlights_description": "A selection of sites that you’ve saved or visited",
  "prefs_highlights_options_visited_label": "Visited Pages",
  "prefs_highlights_options_download_label": "Most Recent Download",
  "prefs_highlights_options_pocket_label": "Pages Saved to Pocket",
  "prefs_snippets_description": "Updates from Mozilla and Firefox",
  "settings_pane_button_label": "ಹೊಸ ಹಾಳೆಯ ಪುಟವನ್ನು ಅಗತ್ಯಾನುಗುಣಗೊಳಿಸಿ",
  "settings_pane_topsites_header": "ಪ್ರಮುಖ ತಾಣಗಳು",
  "settings_pane_highlights_header": "ಮುಖ್ಯಾಂಶಗಳು",
  "settings_pane_highlights_options_bookmarks": "ಪುಟಗುರುತುಗಳು",
  "settings_pane_snippets_header": "ಉಲ್ಲೇಖಗಳು",
  "edit_topsites_button_text": "‍ತಿದ್ದು",
  "edit_topsites_edit_button": "ಈ ತಾಣವನ್ನು ಸಂಪಾದಿಸು",
  "topsites_form_add_header": "ಹೊಸ ಅಗ್ರ ತಾಣಗಳು",
  "topsites_form_edit_header": "ಅಗ್ರ ತಾಣಗಳನ್ನು ಸಂಪಾದಿಸಿ",
  "topsites_form_title_label": "Title",
  "topsites_form_title_placeholder": "ಶೀರ್ಷಿಕೆಯನ್ನು ನಮೂದಿಸಿ",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "Custom Image URL",
  "topsites_form_url_placeholder": "ಒಂದು URL ಅನ್ನು ಟೈಪಿಸಿ ಅಥವಾ ನಕಲಿಸಿ",
  "topsites_form_use_image_link": "Use a custom image…",
  "topsites_form_preview_button": "Preview",
  "topsites_form_add_button": "ಸೇರಿಸು",
  "topsites_form_save_button": "ಉಳಿಸು",
  "topsites_form_cancel_button": "ರದ್ದು ಮಾಡು",
  "topsites_form_url_validation": "ಸರಿಯಾದ URL ಬೇಕಾಗಿದೆ",
  "topsites_form_image_validation": "Image failed to load. Try a different URL.",
  "pocket_read_more": "ಜನಪ್ರಿಯವಾದ ವಿಷಯಗಳು:",
  "pocket_read_even_more": "ಹೆಚ್ಚು ಕತೆಗಳನ್ನು ನೋಡಿರಿ",
  "highlights_empty_state": "ವೀಕ್ಷಣೆ ಮಾಡಲು ಶುರುಮಾಡಿ, ಮತ್ತು ನಾವು ಇತ್ತೀಚೆಗೆ ಭೇಟಿ ನೀಡಿದ ಅಥವಾ ಬುಕ್‌ಮಾರ್ಕ್ ಮಾಡಲಾದ ಕೆಲವು ಶ್ರೇಷ್ಠ ಲೇಖನಗಳು, ವೀಡಿಯೊಗಳು ಮತ್ತು ಇತರ ಪುಟಗಳನ್ನು ನಾವು ತೋರಿಸುತ್ತೇವೆ.",
  "topstories_empty_state": "You’ve caught up. Check back later for more top stories from {provider}. Can’t wait? Select a popular topic to find more great stories from around the web.",
  "manual_migration_explanation2": "Try Firefox with the bookmarks, history and passwords from another browser.",
  "manual_migration_cancel_button": "ಪರವಾಗಿಲ್ಲ",
  "manual_migration_import_button": "ಈಗ ಆಮದು ಮಾಡು",
  "error_fallback_default_info": "Oops, something went wrong loading this content.",
  "error_fallback_default_refresh_suggestion": "Refresh page to try again.",
  "section_menu_action_remove_section": "Remove Section",
  "section_menu_action_collapse_section": "Collapse Section",
  "section_menu_action_expand_section": "Expand Section",
  "section_menu_action_manage_section": "Manage Section",
  "section_menu_action_add_topsite": "Add Top Site",
  "section_menu_action_move_up": "Move Up",
  "section_menu_action_move_down": "Move Down",
  "section_menu_action_privacy_notice": "Privacy Notice",
  "default_label_loading": "ಲೋಡ್ ಆಗುತ್ತಿದೆ…",
  "header_stories": "ಪ್ರಮುಖ ಸುದ್ದಿಗಳು",
  "header_visit_again": "ಮತ್ತೆ ಭೇಟಿಕೊಡು",
  "header_bookmarks": "ಇತ್ತೀಚಿಗೆ ಮಾಡಲಾದ ಬುಕ್‌ಮಾರ್ಕುಗಳು",
  "header_bookmarks_placeholder": "ನಿಮ್ಮ ಹತ್ತಿರ ಇನ್ನೂ ಯಾವುದೇ ಪುಟಗುರುತುಗಳಿಲ್ಲ.",
  "header_stories_from": "ಯಿಂದ",
  "type_label_synced": "ಮತ್ತೊಂದು ಸಾಧನದಿಂದ ಸಿಂಕ್ ಮಾಡಲಾಗಿದೆ",
  "type_label_open": "ತೆರೆ",
  "type_label_topic": "ವಿಷಯ",
  "type_label_now": "ಈಗ",
  "menu_action_copy_address": "ವಿಳಾಸವನ್ನು ನಕಲಿಸು",
  "menu_action_email_link": "ಇಮೈಲ್ ಕೊಂಡಿ…",
  "search_for_something_with": "{search_term} ಅನ್ನು ಇದರಿಂದ ಹುಡುಕಿ:",
  "search_settings": "ಹುಡುಕು ಸಿದ್ಧತೆಗಳನ್ನು ಬದಲಾಯಿಸು",
  "section_info_option": "ಮಾಹಿತಿ",
  "section_info_send_feedback": "ಅಭಿಪ್ರಾಯವನ್ನು ಕಳುಹಿಸಿ",
  "section_info_privacy_notice": "ಗೌಪ್ಯತಾ ಸೂಚನೆ",
  "welcome_title": "ಹೊಸ ಹಾಳೆಗೆ ಸುಸ್ವಾಗತ",
  "time_label_less_than_minute": "<1ನಿ",
  "time_label_minute": "{number}ನಿ",
  "time_label_hour": "{number}ಗ",
  "time_label_day": "{number}ದಿ",
  "settings_pane_header": "ಹೊಸ ಹಾಳೆಯ ಆದ್ಯತೆಗಳು",
  "settings_pane_body2": "ನೀವು ಈ ಪುಟದಲ್ಲಿ ಏನು ನೋಡಿತ್ತೀರೆಂದು ಆಯ್ಕೆಮಾಡಿ.",
  "settings_pane_search_header": "ಹುಡುಕು",
  "settings_pane_search_body": "ಹೊಸ ಹಾಳೆಯಿಂದ ಅಂತರ್ಜಾಲವನ್ನು ಹುಡುಕಿ.",
  "settings_pane_topsites_body": "ನೀವು ಅತಿ ಹೆಚ್ಚು ನೋಡುವ ಜಾಲತಾಣಗಳಿಗೆ ಪ್ರವೇಶದ್ವಾರ.",
  "settings_pane_topsites_options_showmore": "ಎರಡು ಸಾಲುಗಳನ್ನು ಪ್ರದರ್ಶಿಸು",
  "settings_pane_bookmarks_header": "ಇತ್ತೀಚಿನ ಪುಟಗುರುತುಗಳು",
  "settings_pane_visit_again_header": "ಮತ್ತೆ ಭೇಟಿಕೊಡು",
  "settings_pane_highlights_options_visited": "ಭೇಟಿ ನೀಡಿದ ತಾಣಗಳು",
  "settings_pane_done_button": "ಆಯಿತು",
  "edit_topsites_showmore_button": "‍ಹೆಚ್ಚು ತೋರಿಸು",
  "edit_topsites_showless_button": "ಕೆಲವೊಂದು ತೋರಿಸಿ",
  "edit_topsites_done_button": "ಆಯಿತು",
  "edit_topsites_pin_button": "ಈ ತಾಣವನ್ನು ಪಿನ್ ಮಾಡು",
  "edit_topsites_unpin_button": "ಈ ತಾಣವನ್ನು ಹೊರತೆಗೆ",
  "edit_topsites_dismiss_button": "ಈ ತಾಣವನ್ನು ತೆಗೆದುಹಾಕು",
  "edit_topsites_add_button": "ಸೇರಿಸು"
};
